#
# Repository
#

resource "aws_ecr_repository" "default" {
  name = "${var.namespace}/${var.name}"
}

#
# Lifecycle:
#
# - remove untagged
# - keep max `max_images_count` dev images
# - keep max `max_images_count` RC images
# - keep max `max_images_count` release images
#
# https://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html#lp_evaluation_rules
#

resource "aws_ecr_lifecycle_policy" "default" {
  repository = aws_ecr_repository.default.name

  policy = <<EOF
{
  "rules": [
    {
      "rulePriority": 1,
      "description": "Remove untagged images.",
      "selection": {
        "tagStatus": "untagged",
        "countType": "imageCountMoreThan",
        "countNumber": 1
      },
      "action": {
        "type": "expire"
      }
    },
    {
      "rulePriority": 2,
      "description": "Remove dev images when reach ${var.max_images_count} images stored.",
      "selection": {
        "tagStatus": "any",
        "countType": "imageCountMoreThan",
        "countNumber": ${var.max_images_count}
      },
      "action": {
        "type": "expire"
      }
    },
    {
      "rulePriority": 3,
      "description": "Always keep ${var.max_images_count} RC images stored.",
      "selection": {
        "tagStatus": "tagged",
        "tagPrefixList": ["${var.rc_images_prefix}"],
        "countType": "imageCountMoreThan",
        "countNumber": ${var.max_images_count}
      },
      "action": {
        "type": "expire"
      }
    },
    {
      "rulePriority": 4,
      "description": "Always keep ${var.max_images_count} release images stored.",
      "selection": {
        "tagStatus": "tagged",
        "tagPrefixList": ["${var.release_images_prefix}"],
        "countType": "imageCountMoreThan",
        "countNumber": ${var.max_images_count}
      },
      "action": {
        "type": "expire"
      }
    }
  ]
}
EOF
}
