resource "aws_elb" "default" {
  name    = "${var.name}-${var.env}-elb"
  subnets = var.jz_vpc.subnets.*.id

  security_groups = [
    aws_security_group.elb.id,
  ]

  dynamic "listener" {
    for_each = var.port_mapping
    content {
      instance_protocol  = listener.value.app_schema
      instance_port      = listener.value.app_port
      lb_protocol        = listener.value.elb_schema
      lb_port            = listener.value.elb_port
      ssl_certificate_id = listener.value.elb_schema == "https" || listener.value.elb_schema == "ssl" ? data.aws_acm_certificate.default[0].arn : ""
    }
  }

  health_check {
    target              = var.health_check_target
    timeout             = 5
    interval            = 30
    unhealthy_threshold = 10
    healthy_threshold   = 2
  }

  instances = flatten([
    var.jz_swarm_project.instance_ids.leader,
    var.jz_swarm_project.instance_ids.managers.*,
    var.jz_swarm_project.instance_ids.workers.*]
  )

  cross_zone_load_balancing   = true
  idle_timeout                = 400
  connection_draining         = true
  connection_draining_timeout = 400

  tags = {
    Name = "${var.name}-${var.env}-elb"
    Env  = var.env
  }
}

data "aws_acm_certificate" "default" {
  count       = var.ssl_cert_domain != "" ? 1 : 0
  domain      = var.ssl_cert_domain
  most_recent = true
}
