#
# Key for System Parameters access
#

resource "aws_kms_key" "params_storage" {
  description             = "KMS key for Docker Swarm Parameters Storage."
  deletion_window_in_days = 7

  tags = {
    Name = "${var.env}-params-storage-key"
    Env  = var.env
  }
}

#
# Assign alias for readability in console
#

resource "aws_kms_alias" "params_storage_alias" {
  name = "alias/jazzy/docker/swarm/${var.env}-key"
  target_key_id = aws_kms_key.params_storage.key_id
}

#
# KMS grants for managers and workers
#

resource "aws_kms_grant" "manager" {
  name              = "manager-grant"
  key_id            = aws_kms_key.params_storage.key_id
  grantee_principal = var.jz_swarm_global.iam_roles.swarm_manager.arn
  operations        = [
    "Encrypt",
    "Decrypt",
    "GenerateDataKey",
  ]
}

resource "aws_kms_grant" "worker" {
  name              = "worker-grant"
  key_id            = aws_kms_key.params_storage.key_id
  grantee_principal = var.jz_swarm_global.iam_roles.swarm_worker.arn
  operations        = [
    "Encrypt",
    "Decrypt",
    "GenerateDataKey",
  ]
}
