#
# Regular EFS
#

resource "aws_efs_file_system" "regular_efs" {
  performance_mode = "generalPurpose"
  throughput_mode  = "bursting"

  lifecycle_policy {
    transition_to_ia = "AFTER_30_DAYS"
  }

  tags = {
    Name = "${var.name}-${var.env}-regular-efs"
  }
}

resource "aws_efs_mount_target" "regular_efs_mt" {
  count          = length(var.jz_vpc.subnets)
  file_system_id = aws_efs_file_system.regular_efs.id
  subnet_id      = var.jz_vpc.subnets[count.index].id

  security_groups = [
    var.jz_swarm_generic.vpc_security_group.id
  ]
}

#
# MaxIO EFS
#

resource "aws_efs_file_system" "maxio_efs" {
  performance_mode = "maxIO"
  throughput_mode  = "bursting"

  lifecycle_policy {
    transition_to_ia = "AFTER_30_DAYS"
  }

  tags = {
    Name = "${var.name}-${var.env}-maxio-efs"
  }
}

resource "aws_efs_mount_target" "maxio_efs_mt" {
  count          = length(var.jz_vpc.subnets)
  file_system_id = aws_efs_file_system.maxio_efs.id
  subnet_id      = var.jz_vpc.subnets[count.index].id

  security_groups = [
    var.jz_swarm_generic.vpc_security_group.id
  ]
}